@@ -6,7 +6,7 @@
 # Change 1..1 below to 1..last_test_to_print .
 # (It may become useful if the test is moved to ./t subdirectory.)
 
-BEGIN { $| = 1; print "1..1\n"; }
+BEGIN { $| = 1; print "1..3\n"; }
 END {print "not ok 1\n" unless $loaded;}
 use File::Repl;
 $loaded = 1;
@@ -17,4 +17,28 @@ print "ok 1\n";
 # Insert your test code below (better if it prints "ok 13"
 # (correspondingly "not ok 13") depending on the success of chunk 13
 # of the test code):
+ 
 
+%con = (
+    dira     => 'C:/temp',
+    dirb     => 'd:/temp',
+    verbose  => '1',
+    age      => '10',
+);
+
+  if ($ref=File::Repl->New(\%con)){
+  	  print "ok 2 (sucessfully created New instance of File::Repl)\n";
+  
+  }
+  
+  if ($ver = $ref->Version){
+	  print "ok 3 (File::Repl reports version as $ver)\n";
+    }
+  
+  exit;
+  
+  
+  
+  
+  $r1 = $ref->Update('\.p(l|m)','a<>b',1);
+  $r2 = $ref->Update('\.t.*','\.tmp$','a<>b',1);
